==> mindee-2.1.0-py3-none-any.whl: mindee/documents/custom_document.py <==
from typing import Dict, List

from mindee.documents.base import Document
from mindee.http import Endpoint


class CustomDocument(Document):
    fields: Dict[str, dict] = {}

    def __init__(
        self,
        document_type: str,
        api_prediction=None,
        input_file=None,
        page_n: int = 0,
    ):
        """
        :param document_type: Document type
        :param api_prediction: Raw prediction from HTTP response
        :param input_file: Input object
        :param page_n: Page number for multi pages pdf input
        """
        super().__init__(
            input_file=input_file,
            document_type=document_type,
            api_prediction=api_prediction,
            page_n=page_n,
        )

    def build_from_api_prediction(self, api_prediction, page_n: int = 0):
        """
        :param api_prediction: Raw prediction from HTTP response
        :param page_n: Page number for multi pages pdf input
        :return: (void) set the object attributes with api prediction values
        """
        for field_name in api_prediction:
            field = api_prediction[field_name]
            field["page_n"] = page_n
            self.fields[field_name] = field
            setattr(self, field_name, field)

    def __str__(self) -> str:
        """
        :return: (str) String representation of the document
        """
        custom_doc_str = f"----- {self.type} -----\n"
        for name, info in self.fields.items():
            custom_doc_str += "%s: %s\n" % (
                name,
                "".join([value["content"] for value in info["values"]]),
            )
        custom_doc_str += "-----------------\n"
        return custom_doc_str

    @staticmethod
    def request(endpoints: List[Endpoint], input_file, include_words: bool = False):
        """
        Make request to expense_receipts endpoint
        :param include_words: Not yet used for custom documents
        :param input_file: Input object
        :param endpoints: Endpoints config
        """
        return endpoints[0].predict_request(input_file, include_words)

    def _checklist(self):
        return {}

==> mindee-2.4.0-py3-none-any.whl: mindee/documents/custom_document.py <==
from typing import Dict, Optional

from mindee.documents.base import Document, TypeApiPrediction


class CustomDocument(Document):
    fields: Dict[str, dict] = {}
    """Dictionary of all fields in the document"""

    def __init__(
        self,
        document_type: str,
        api_prediction: TypeApiPrediction,
        input_file=None,
        page_n: Optional[int] = None,
    ):
        """
        Custom document object.

        :param document_type: Document type
        :param api_prediction: Raw prediction from HTTP response
        :param input_file: Input object
        :param page_n: Page number for multi pages pdf input
        """
        super().__init__(
            input_file=input_file,
            document_type=document_type,
            api_prediction=api_prediction,
            page_n=page_n,
        )

    def _build_from_api_prediction(
        self, api_prediction: TypeApiPrediction, page_n: Optional[int] = None
    ) -> None:
        """
        Build the document from an API response JSON.

        :param api_prediction: Raw prediction from HTTP response
        :param page_n: Page number for multi pages pdf input
        """
        for field_name in api_prediction:
            field = api_prediction[field_name]
            field["page_n"] = page_n
            self.fields[field_name] = field
            setattr(self, field_name, field)

    def __str__(self) -> str:
        custom_doc_str = f"----- {self.type} -----\n"
        for name, info in self.fields.items():
            custom_doc_str += "%s: %s\n" % (
                name,
                " ".join([value["content"] for value in info["values"]]),
            )
        custom_doc_str += "----------------------"
        return custom_doc_str

    def _checklist(self) -> None:
        pass
